# Debug

setting pycharm to debug application:

![debug1](img/debug_s3_pull_processor_in_pycharm.png)

pytest for TDD:

![debug1](img/debug_pytest.png)

remember to set AWS variables:

![debug1](img/debug_AWS_creds.png)
